Changelog - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Changelog

1.0.0-beta8 – February 05, 2021

- update dependencies
- new vector maps demos
- fixes update map on resize
- docs improvement
- replace `badge` with `status-dot` in `navbar-notifications.html`
- map tooltip fixes

1.0.0-beta7 – February 05, 2021

- fix: #1019 - project-overview.html link not working
- fix: #1010 - card with bottom tabs has incorrect border radius
- uptime monitor mobile fixes
- navbar dark button fix
- `tabler-icons` link
- autoloading webfonts
- cards fixes, new cards demos
- ruby dependencies update
- RTL stylesheet fixes
- new card action demos

1.0.0-beta6 – January 18, 2021

- pricing cards fix
- fix bug `fw-...`, `.fs-...` is missed (#987)
- avatar class fix
- fix bug #903 `litepicker` with date range not having correct border
- page wrapper fix
- fix #900 `is-invalid-lite` class is not working under `was-validated` form class
- update `@tabler/icons` to version 1.48
- fix #960 - Badges not honoring font sizes
- fix #959 - `node-sass` does not properly compile nested media queries
- update package dependencies to newest version

1.0.0-beta5 – December 07, 2021

Tabler has finally lived to see dark mode! 🌝🌚

- Dark mode enabled!
- add more cursors (#947)
- fix #892 - Media queries need to be nested when negating
- update `@tabler/icons` to newest version
- move optional dependencies to peerDependencies (#924)
- move deployment to Github Actions (#934)
- table border fixes
- antialiased fix
- update `@tabler/icons` to version 1.42
- change default font to ‘Inter’
- colors unify
- add `tom-select` and remove `choices.js`

1.0.0-beta4 – October 24, 2021

- upgrade required node.js version to 14
- upgrade Bootstrap to 5.1
- upgrade dependencies
- fix #775 litepicker not initializing
- fix `nouislider` import in dev

1.0.0-beta3 – May 08, 2021

- upgrade Bootstrap to 5.0
- upgrade dependencies
- change `$border-radius-pill` variable
- badge vertical align fix

1.0.0-beta2 – March 29, 2021

- update dependencies
- `li` marker fix
- page wrapper, nav fixes
- scripts optimize, remove `capture_once`
- `page-body` fixes
- layout navbar fix
- typography fix
- ribbon fix
- charts label fixes
- charts docs

1.0.0-beta – February 17, 2021

Initial beta release of Tabler v1.0! Lots more coming soon though 😁

- update Bootstrap to 5.0.0-beta2
- update other dependencies.